summaryrefslogtreecommitdiffstats
path: root/kioslaves/imap4/rfcdecoder.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kioslaves/imap4/rfcdecoder.cc')
-rw-r--r--kioslaves/imap4/rfcdecoder.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/kioslaves/imap4/rfcdecoder.cc b/kioslaves/imap4/rfcdecoder.cc
index 0aa237d6..5470901e 100644
--- a/kioslaves/imap4/rfcdecoder.cc
+++ b/kioslaves/imap4/rfcdecoder.cc
@@ -154,7 +154,7 @@ TQString rfcDecoder::fromIMAP (const TQString & inSrc)
return TQString::fromUtf8 (dst.data ());
}
/* replace " with \" and \ with \\ " and \ characters */
TQString rfcDecoder::quoteIMAP(const TQString &src)
{
uint len = src.length();
@@ -311,7 +311,7 @@ rfcDecoder::codecForName (const TQString & _str)
if (_str.isEmpty ())
return NULL;
return TQTextCodec::codecForName (_str.lower ().
- replace ("windows", "cp").latin1 ());
+ tqreplace ("windows", "cp").latin1 ());
}
//-----------------------------------------------------------------------------
@@ -154,7 +154,7 @@ TQString rfcDecoder::fromIMAP (const TQString & inSrc)
return TQString::fromUtf8 (dst.data ());
}
-/* replace " with \" and \ with \\ " and \ characters */
+/* tqreplace " with \" and \ with \\ " and \ characters */
TQString rfcDecoder::quoteIMAP(const TQString &src)
{